

from ufl.geometry import domain2dim
from sfc.geometry.UFCCell import UFCCell
from sfc.geometry.affine_map import gen_geometry_code
from sfc.geometry.mappings import geometry_mapping

